@@ -113,6 +113,8 @@ sub new {
   return $that->SUPER::new(undef,Src=>$src,Pattern=>$pat,Replacement=>$repl,Modifiers=>$mods,IsGlobal=>0,%opts);
 }
 
+sub Children { [grep {defined($_)} $_[0]{Src}]; }
+
 sub Clear { delete $_[0]{Src}; }
 sub toString {
   return '(' . $_[0]{Src}->toString . " ~ s/$_[0]{Pattern}/$_[0]{Replacement}/$_[0]{Modifiers})";
@@ -196,6 +198,8 @@ sub new {
   return $that->SUPER::new('COUNT',Dtr=>$dtr,Keys=>$keys,Sample=>($samp||-1),Sort=>($sort||DDC::PP::NoSort),Lo=>$lo,Hi=>$hi,%opts);
 }
 
+sub Children { [grep {defined($_)} @{$_[0]}{qw(Dtr Keys)}]; }
+
 sub Clear { delete @{$_[0]}{qw(Dtr Keys)}; }
 sub GetMatchId {
   return (($_[0]{Keys} && $_[0]{Keys}->GetMatchId)
