@@ -56,6 +56,7 @@ __PACKAGE__->nomethod('self');
 __PACKAGE__->nomethod('free');
 
 #__PACKAGE__->nomethod('Children');
+#  + override this if order is important (e.g. for DiaCollo CQWith, CQAnd, etc.)
 sub Children {
   return UNIVERSAL::isa($_[0],'HASH') ? [grep {UNIVERSAL::isa($_,'DDC::PP::Object')} values %{$_[0]}] : [];
 }
@@ -67,13 +68,11 @@ sub Descendants {
   my @kids    = qw();
   my ($obj);
   while (@stack) {
-    $obj = pop(@stack);
+    $obj = shift(@stack);
     next if (exists $visited{$obj});
     push(@kids,$obj);
     $visited{$obj} = undef;
-    foreach (ref($obj) ? @{$obj->Children} : qw()) {
-      push(@stack,$_);
-    }
+    unshift(@stack, @{$obj->Children}) if (ref($obj));
   }
   return \@kids;
 }
